RemoteConfig class

Mixed-in types

Constructors

RemoteConfig({String? key, Map<String, dynamic>? defaults, int? fetchTimeout, int? minimumFetchInterval, FirebaseApp? app})
Constructor takes in default values

Properties

activated → bool
Indicates if activated.
no setter
hasError → bool
Indicates if an error has occurred or not.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
inError → bool
Indicates if an error has occurred or not.
no setter
instance → FirebaseRemoteConfig?
References an instance of the underlying Firebase Remote Config plugin.
no setter
isInit → bool
Indicates if initialized correctly.
no setter
lastFetchStatus → RemoteConfigFetchStatus
Returns the status of the last attempt to fetch Remote Config value.
no setter
lastFetchTime → DateTime
Returns the last time a Remote Config value was retrieved. If no successful the epoch (1970-01-01 UTC) is returned.
no setter
remoteConfigSettings → RemoteConfigSettings
Returns the current Remote Config settings.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate() → Future<bool>
Makes the last fetched config available to getters.
addListener(VoidCallback listener) → void
Add a listener to trigger when a Firebase Remote Config value is changed.
override
dispose() → void
Cleans up the Firebase Remote Config plugin.
override
en(String data, [String? key]) → Future<String>
Return encrypted String
ensureInitialized() → Future<bool>
Ensures the last activated config are available to getters.
fetch() → Future<bool>
Fetches and caches configuration from the Remote Config service.
fetchAndActivate({bool? throwError}) → Future<bool>
Performs a fetch and activate operation, as a convenience.
getAll() → Map<String, RemoteConfigValue>
Returns all the 'Remote Config' values from Firebase Remote Config.
getBool(String key) → bool
Returns an boolean value from Firebase Remote Config.
getDouble(String key) → double
Returns an double value from Firebase Remote Config.
getError([Object? error]) → Exception?
Returns the last error that may occurred. Records an error as well.
getInt(String key) → int
Returns an integer value from Firebase Remote Config.
getString(String key) → String
Returns a String value from Firebase Remote Config.
getStringed(String param, [String? key]) → Future<String>
Returns a decrypted String value from Firebase Remote Config.
getValue(String key) → RemoteConfigValue
Returns an 'Remote Config' value from Firebase Remote Config.
initAsync() → Future<bool>
Initializes the Firebase Remote Config plugin.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a specified listener
override
setConfigSettings(RemoteConfigSettings? remoteConfigSettings) → Future<bool>
Sets the Remote Config settings.
setDefaults(Map<String, dynamic>? defaults) → Future<bool>
Set the default Firebase Remote Config values
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited