RemoteConfigSettings class

Defines the options for the corresponding Remote Config instance.

Constructors

RemoteConfigSettings({required Duration fetchTimeout, required Duration minimumFetchInterval})
Constructs an instance of RemoteConfigSettings with given fetchTimeout and minimumFetchInterval.

Properties

fetchTimeout ↔ Duration
Maximum Duration to wait for a response when fetching configuration from the Remote Config server.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minimumFetchInterval ↔ Duration
Maximum age of a cached config before it is considered stale.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited