RemoteConfigValue class

RemoteConfigValue encapsulates the value and source of a Remote Config parameter.

Constructors

RemoteConfigValue(List<int>? _value, ValueSource source)
Wraps a value with metadata and type-safe getters.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ValueSource
Indicates at which source this value came from.
final

Methods

asBool() → bool
Decode value to bool.
asDouble() → double
Decode value to double.
asInt() → int
Decode value to int.
asString() → String
Decode value to string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultValueForBool → const bool
Default value for Bool
defaultValueForDouble → const double
Default value for Double
defaultValueForInt → const int
Default value for Int
defaultValueForString → const String
Default value for String